# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/data/frame.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from blickfeld import options_pb2 as blickfeld_dot_options__pb2
from blickfeld.config import scan_pattern_pb2 as blickfeld_dot_config_dot_scan__pattern__pb2
from blickfeld.data import scanline_pb2 as blickfeld_dot_data_dot_scanline__pb2
from blickfeld.data import algorithm_pb2 as blickfeld_dot_data_dot_algorithm__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/data/frame.proto',
  package='blickfeld.protocol.data',
  syntax='proto2',
  serialized_options=b'\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x62lickfeld/data/frame.proto\x12\x17\x62lickfeld.protocol.data\x1a\x17\x62lickfeld/options.proto\x1a#blickfeld/config/scan_pattern.proto\x1a\x1d\x62lickfeld/data/scanline.proto\x1a\x1e\x62lickfeld/data/algorithm.proto\"\x8e\x05\n\x05\x46rame\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x1b\n\rstart_time_ns\x18\x03 \x01(\x04\x42\x04\xb0\xb5\x18\x01\x12\x42\n\x0cscan_pattern\x18\x05 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPatternB\x04\xb0\xb5\x18\x01\x12\x1e\n\x10is_ramp_up_phase\x18\t \x01(\x08\x42\x04\xb0\xb5\x18\x01\x12\x1e\n\x16total_number_of_points\x18\x06 \x01(\r\x12\x1f\n\x17total_number_of_returns\x18\x07 \x01(\r\x12:\n\tscanlines\x18\x02 \x03(\x0b\x32!.blickfeld.protocol.data.ScanlineB\x04\xb0\xb5\x18\x01\x12;\n\x06packed\x18\x08 \x01(\x0b\x32%.blickfeld.protocol.data.Frame.PackedB\x04\xb0\xb5\x18\x01\x12\x36\n\nalgorithms\x18\n \x03(\x0b\x32\".blickfeld.protocol.data.Algorithm\x1a\x85\x02\n\x06Packed\x12\x0e\n\x06length\x18\x01 \x01(\r\x12\x17\n\tcartesian\x18\x02 \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12\x17\n\tdirection\x18\x03 \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12\x13\n\x05range\x18\x04 \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12\x17\n\tintensity\x18\x05 \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12!\n\x13\x61mbient_light_level\x18\x06 \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12\x1d\n\x0fstart_offset_ns\x18\x07 \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12\x16\n\x08point_id\x18\x08 \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12\x18\n\nchannel_id\x18\t \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x12\x17\n\treturn_id\x18\n \x01(\x0c\x42\x04\xb0\xb5\x18\x01\x42\x03\xf8\x01\x01'
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_config_dot_scan__pattern__pb2.DESCRIPTOR,blickfeld_dot_data_dot_scanline__pb2.DESCRIPTOR,blickfeld_dot_data_dot_algorithm__pb2.DESCRIPTOR,])




_FRAME_PACKED = _descriptor.Descriptor(
  name='Packed',
  full_name='blickfeld.protocol.data.Frame.Packed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='length', full_name='blickfeld.protocol.data.Frame.Packed.length', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cartesian', full_name='blickfeld.protocol.data.Frame.Packed.cartesian', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='blickfeld.protocol.data.Frame.Packed.direction', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range', full_name='blickfeld.protocol.data.Frame.Packed.range', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intensity', full_name='blickfeld.protocol.data.Frame.Packed.intensity', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ambient_light_level', full_name='blickfeld.protocol.data.Frame.Packed.ambient_light_level', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_offset_ns', full_name='blickfeld.protocol.data.Frame.Packed.start_offset_ns', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_id', full_name='blickfeld.protocol.data.Frame.Packed.point_id', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='blickfeld.protocol.data.Frame.Packed.channel_id', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_id', full_name='blickfeld.protocol.data.Frame.Packed.return_id', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=574,
  serialized_end=835,
)

_FRAME = _descriptor.Descriptor(
  name='Frame',
  full_name='blickfeld.protocol.data.Frame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blickfeld.protocol.data.Frame.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time_ns', full_name='blickfeld.protocol.data.Frame.start_time_ns', index=1,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scan_pattern', full_name='blickfeld.protocol.data.Frame.scan_pattern', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_ramp_up_phase', full_name='blickfeld.protocol.data.Frame.is_ramp_up_phase', index=3,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_number_of_points', full_name='blickfeld.protocol.data.Frame.total_number_of_points', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_number_of_returns', full_name='blickfeld.protocol.data.Frame.total_number_of_returns', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scanlines', full_name='blickfeld.protocol.data.Frame.scanlines', index=6,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed', full_name='blickfeld.protocol.data.Frame.packed', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='algorithms', full_name='blickfeld.protocol.data.Frame.algorithms', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FRAME_PACKED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=835,
)

_FRAME_PACKED.containing_type = _FRAME
_FRAME.fields_by_name['scan_pattern'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_FRAME.fields_by_name['scanlines'].message_type = blickfeld_dot_data_dot_scanline__pb2._SCANLINE
_FRAME.fields_by_name['packed'].message_type = _FRAME_PACKED
_FRAME.fields_by_name['algorithms'].message_type = blickfeld_dot_data_dot_algorithm__pb2._ALGORITHM
DESCRIPTOR.message_types_by_name['Frame'] = _FRAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Frame = _reflection.GeneratedProtocolMessageType('Frame', (_message.Message,), {

  'Packed' : _reflection.GeneratedProtocolMessageType('Packed', (_message.Message,), {
    'DESCRIPTOR' : _FRAME_PACKED,
    '__module__' : 'blickfeld.data.frame_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.data.Frame.Packed)
    })
  ,
  'DESCRIPTOR' : _FRAME,
  '__module__' : 'blickfeld.data.frame_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.data.Frame)
  })
_sym_db.RegisterMessage(Frame)
_sym_db.RegisterMessage(Frame.Packed)


DESCRIPTOR._options = None
_FRAME_PACKED.fields_by_name['cartesian']._options = None
_FRAME_PACKED.fields_by_name['direction']._options = None
_FRAME_PACKED.fields_by_name['range']._options = None
_FRAME_PACKED.fields_by_name['intensity']._options = None
_FRAME_PACKED.fields_by_name['ambient_light_level']._options = None
_FRAME_PACKED.fields_by_name['start_offset_ns']._options = None
_FRAME_PACKED.fields_by_name['point_id']._options = None
_FRAME_PACKED.fields_by_name['channel_id']._options = None
_FRAME_PACKED.fields_by_name['return_id']._options = None
_FRAME.fields_by_name['start_time_ns']._options = None
_FRAME.fields_by_name['scan_pattern']._options = None
_FRAME.fields_by_name['is_ramp_up_phase']._options = None
_FRAME.fields_by_name['scanlines']._options = None
_FRAME.fields_by_name['packed']._options = None
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.config.scan_pattern_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class NamedScanPattern(google.protobuf.message.Message):
    """*
    > Introduced in BSL v2.15 and firmware v1.16

    Named scan patterns are saved on the device. There are two kinds of named scan patterns:
    1. Default scan patterns: Each device has default scan patterns, these are saved on the device with the firmware. They are not changeable.
    2. Custom scan patterns: Users can save scan patterns on the device for later use. If the scan pattern is saved as a named scan pattern, the time changing to this scan pattern will greatly decrease.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    """The name has to be different of the default scan patterns and can only contain letters, numbers, space, underscore and minus."""

    @property
    def config(self) -> blickfeld.config.scan_pattern_pb2.ScanPattern:
        """Scan pattern config, refer to [ScanPattern](#blickfeld.protocol.config.ScanPattern)"""
        pass
    read_only: builtins.bool = ...
    """this is an read_only flag and it will be set if this is a default scan pattern, which can't be changed or deleted."""

    def __init__(self,
        *,
        name : typing.Optional[typing.Text] = ...,
        config : typing.Optional[blickfeld.config.scan_pattern_pb2.ScanPattern] = ...,
        read_only : typing.Optional[builtins.bool] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"config",b"config",u"name",b"name",u"read_only",b"read_only"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"config",b"config",u"name",b"name",u"read_only",b"read_only"]) -> None: ...
global___NamedScanPattern = NamedScanPattern



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.common_pb2
import blickfeld.config.advanced_pb2
import blickfeld.config.named_scan_pattern_pb2
import blickfeld.config.product_pb2
import blickfeld.config.scan_pattern_pb2
import blickfeld.error_pb2
import blickfeld.status.main_pb2
import blickfeld.stream.connection_pb2
import blickfeld.stream.event_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Format(_Format, metaclass=_FormatEnumTypeWrapper):
    """*
    The format type of response is an undocumented, internal feature required for the REST API.
    """
    pass
class _Format:
    V = typing.NewType('V', builtins.int)
class _FormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Format.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    PROTOBUF = Format.V(1)
    JSON = Format.V(2)

PROTOBUF = Format.V(1)
JSON = Format.V(2)
global___Format = Format


class Request(google.protobuf.message.Message):
    """*
    This section describes the different requests a client can send to the server.
    A request is always answered with a response. For every response, there is a request with the same name.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Hello(google.protobuf.message.Message):
        """*
        This request is used for initial communication after connecting to a device and testing the established connection.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        PROTOCOL_VERSION_FIELD_NUMBER: builtins.int
        LIBRARY_VERSION_FIELD_NUMBER: builtins.int
        LANGUAGE_FIELD_NUMBER: builtins.int
        protocol_version: builtins.int = ...
        """Version of the Blickfeld protocol"""

        library_version: typing.Text = ...
        """<blockquote>Introduced in BSL v2.16 and firmware v1.17</blockquote>  Library version"""

        language: blickfeld.common_pb2.Language.V = ...
        """<blockquote>Introduced in BSL v2.16 and firmware v1.17</blockquote>  Library language"""

        def __init__(self,
            *,
            protocol_version : typing.Optional[builtins.int] = ...,
            library_version : typing.Optional[typing.Text] = ...,
            language : typing.Optional[blickfeld.common_pb2.Language.V] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"language",b"language",u"library_version",b"library_version",u"protocol_version",b"protocol_version"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"language",b"language",u"library_version",b"library_version",u"protocol_version",b"protocol_version"]) -> None: ...

    class ProxyHello(google.protobuf.message.Message):
        """*
        Internal use only

        This request is used by internal proxy implementation to forward the correct ip address to the server.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        IP_ADDRESS_FIELD_NUMBER: builtins.int
        ip_address: typing.Text = ...
        """IP address of the real client"""

        def __init__(self,
            *,
            ip_address : typing.Optional[typing.Text] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"ip_address",b"ip_address"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"ip_address",b"ip_address"]) -> None: ...

    class Developer(google.protobuf.message.Message):
        """*
        Internal use only
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class SetScanPattern(google.protobuf.message.Message):
        """*
        This request is used for setting a Scan Pattern.
        A Scan Pattern can either be set by providing a Scan Pattern configuration or a name of a named Scan Pattern.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CONFIG_FIELD_NUMBER: builtins.int
        NAME_FIELD_NUMBER: builtins.int
        PERSIST_FIELD_NUMBER: builtins.int
        @property
        def config(self) -> blickfeld.config.scan_pattern_pb2.ScanPattern:
            """Refer to [ScanPattern](#blickfeld.protocol.config.ScanPattern)"""
            pass
        name: typing.Text = ...
        """Set named Scan Pattern, refer to [NamedScanPattern](#blickfeld.protocol.config.NamedScanPattern)"""

        persist: builtins.bool = ...
        """Persists the scan pattern and sets it after a power cycle. Default: False"""

        def __init__(self,
            *,
            config : typing.Optional[blickfeld.config.scan_pattern_pb2.ScanPattern] = ...,
            name : typing.Optional[typing.Text] = ...,
            persist : typing.Optional[builtins.bool] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"config",b"config",u"data",b"data",u"name",b"name",u"persist",b"persist"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"config",b"config",u"data",b"data",u"name",b"name",u"persist",b"persist"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal[u"data",b"data"]) -> typing.Optional[typing_extensions.Literal["config","name"]]: ...

    class FillScanPattern(google.protobuf.message.Message):
        """*
        This request is used to fill an empty or partially filled scan pattern with the required parameters.
        It will fill the given scan pattern with default values and return the filled scan pattern to the client.
        The filled scan pattern can then be set as input for  [Request.SetScanPattern](#blickfeld.protocol.Request.SetScanPattern).
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CONFIG_FIELD_NUMBER: builtins.int
        @property
        def config(self) -> blickfeld.config.scan_pattern_pb2.ScanPattern:
            """Refer to [ScanPattern](#blickfeld.protocol.config.ScanPattern)"""
            pass
        def __init__(self,
            *,
            config : typing.Optional[blickfeld.config.scan_pattern_pb2.ScanPattern] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"config",b"config"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"config",b"config"]) -> None: ...

    class GetScanPattern(google.protobuf.message.Message):
        """*
        This request is used to retrieve the currently set [ScanPattern](#blickfeld.protocol.config.ScanPattern).
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class Status(google.protobuf.message.Message):
        """*
        This request is used for receiving the current [Status](#blickfeld.protocol.status.Status).
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class RunSelfTest(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.10 and firmware v1.9

        This request triggers a self test of the device.
        It validates the hardware, operates the device, and generates a report.
        The report is currently only accessible by developers.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class SetAdvancedConfig(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.11 and firmware v1.11

        This request is used for configuring the advanced config.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CONFIG_FIELD_NUMBER: builtins.int
        PERSIST_FIELD_NUMBER: builtins.int
        @property
        def config(self) -> blickfeld.config.advanced_pb2.Advanced:
            """Refer to [Advanced](#blickfeld.protocol.config.Advanced)"""
            pass
        persist: builtins.bool = ...
        """Persists the config and sets it after a power cycle. Default: True"""

        def __init__(self,
            *,
            config : typing.Optional[blickfeld.config.advanced_pb2.Advanced] = ...,
            persist : typing.Optional[builtins.bool] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"config",b"config",u"persist",b"persist"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"config",b"config",u"persist",b"persist"]) -> None: ...

    class GetAdvancedConfig(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.11 and firmware v1.11

        This request is used to retrieve the currently set [Advanced](#blickfeld.protocol.config.Advanced).
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class AttemptErrorRecovery(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.13 and firmware v1.13

        This request can be used to attempt a re-initialization of the device if it is errored.
        A self test is automatically triggered after a successful re-initialization.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class GetScanPatternConstraints(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.14 and firmware v1.14

        This request returns a list of constraints which are applied on scan patterns.
        The constraints define the constant and dynamic relationships between field values.
        The constraints are equal for a device type and firmware, but might vary for firmware releases and device variants.
        It is mainly used to visualize the constraints in the scan pattern configuration of the web gui.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class GetNamedScanPatterns(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.15 and firmware v1.16

        This request returns a list of named scan patterns.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class StoreNamedScanPattern(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.15 and firmware v1.16

        This request sets a named scan patterns.
        The name has to be different of the default scan patterns and can only contain letters, numbers, space, underscore and minus.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        NAME_FIELD_NUMBER: builtins.int
        CONFIG_FIELD_NUMBER: builtins.int
        name: typing.Text = ...
        """Name"""

        @property
        def config(self) -> blickfeld.config.scan_pattern_pb2.ScanPattern:
            """Refer to [ScanPattern](#blickfeld.protocol.config.ScanPattern)"""
            pass
        def __init__(self,
            *,
            name : typing.Optional[typing.Text] = ...,
            config : typing.Optional[blickfeld.config.scan_pattern_pb2.ScanPattern] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"config",b"config",u"name",b"name"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"config",b"config",u"name",b"name"]) -> None: ...

    class DeleteNamedScanPattern(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.15 and firmware v1.16

        This request deletes a named scan pattern.
        Default scan patterns can't be deleted.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        NAME_FIELD_NUMBER: builtins.int
        name: typing.Text = ...
        """Name"""

        def __init__(self,
            *,
            name : typing.Optional[typing.Text] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"name",b"name"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"name",b"name"]) -> None: ...

    HELLO_FIELD_NUMBER: builtins.int
    DEVELOPER_FIELD_NUMBER: builtins.int
    SET_SCAN_PATTERN_FIELD_NUMBER: builtins.int
    FILL_SCAN_PATTERN_FIELD_NUMBER: builtins.int
    GET_SCAN_PATTERN_FIELD_NUMBER: builtins.int
    SUBSCRIBE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RUN_SELF_TEST_FIELD_NUMBER: builtins.int
    SET_ADVANCED_CONFIG_FIELD_NUMBER: builtins.int
    GET_ADVANCED_CONFIG_FIELD_NUMBER: builtins.int
    UNSUBSCRIBE_FIELD_NUMBER: builtins.int
    ATTEMPT_ERROR_RECOVERY_FIELD_NUMBER: builtins.int
    GET_SCAN_PATTERN_CONSTRAINTS_FIELD_NUMBER: builtins.int
    GET_NAMED_SCAN_PATTERNS_FIELD_NUMBER: builtins.int
    STORE_NAMED_SCAN_PATTERN_FIELD_NUMBER: builtins.int
    DELETE_NAMED_SCAN_PATTERN_FIELD_NUMBER: builtins.int
    PROXY_HELLO_FIELD_NUMBER: builtins.int
    _ASJSON_FIELD_NUMBER: builtins.int
    ACCEPT_FORMAT_FIELD_NUMBER: builtins.int
    @property
    def hello(self) -> global___Request.Hello:
        """Refer to [Request.Hello](#blickfeld.protocol.Request.Hello)"""
        pass
    @property
    def developer(self) -> global___Request.Developer:
        """Refer to [Request.Developer](#blickfeld.protocol.Request.Developer)"""
        pass
    @property
    def set_scan_pattern(self) -> global___Request.SetScanPattern:
        """Refer to [Request.SetScanPattern](#blickfeld.protocol.Request.SetScanPattern)"""
        pass
    @property
    def fill_scan_pattern(self) -> global___Request.FillScanPattern:
        """Refer to [Request.FillScanPattern](#blickfeld.protocol.Request.FillScanPattern)"""
        pass
    @property
    def get_scan_pattern(self) -> global___Request.GetScanPattern:
        """Refer to [Request.GetScanPattern](#blickfeld.protocol.Request.GetScanPattern)"""
        pass
    @property
    def subscribe(self) -> blickfeld.stream.connection_pb2.Subscribe:
        """Refer to [Subscribe](#blickfeld.protocol.stream.Subscribe)"""
        pass
    @property
    def status(self) -> global___Request.Status:
        """Refer to [Request.Status](#blickfeld.protocol.Request.Status)"""
        pass
    @property
    def run_self_test(self) -> global___Request.RunSelfTest:
        """Refer to [Request.RunSelfTest](#blickfeld.protocol.Request.RunSelfTest)"""
        pass
    @property
    def set_advanced_config(self) -> global___Request.SetAdvancedConfig:
        """<blockquote>Introduced in BSL v2.11 and firmware v1.11</blockquote> Refer to [Request.SetAdvancedConfig](#blickfeld.protocol.Request.SetAdvancedConfig)"""
        pass
    @property
    def get_advanced_config(self) -> global___Request.GetAdvancedConfig:
        """<blockquote>Introduced in BSL v2.11 and firmware v1.11</blockquote> Refer to [Request.GetAdvancedConfig](#blickfeld.protocol.Request.GetAdvancedConfig)"""
        pass
    @property
    def unsubscribe(self) -> blickfeld.stream.connection_pb2.Subscribe:
        """<blockquote>Introduced in BSL v2.13 and firmware v1.13</blockquote> Unsubscribe a stream started with a [Subscribe](#blickfeld.protocol.stream.Subscribe) request."""
        pass
    @property
    def attempt_error_recovery(self) -> global___Request.AttemptErrorRecovery:
        """<blockquote>Introduced in BSL v2.13 and firmware v1.13</blockquote> Refer to [Request.AttemptErrorRecovery](#blickfeld.protocol.Request.AttemptErrorRecovery)"""
        pass
    @property
    def get_scan_pattern_constraints(self) -> global___Request.GetScanPatternConstraints:
        """<blockquote>Introduced in BSL v2.14 and firmware v1.14</blockquote> Refer to [Request.GetScanPatternConstraints](#blickfeld.protocol.Request.GetScanPatternConstraints)"""
        pass
    @property
    def get_named_scan_patterns(self) -> global___Request.GetNamedScanPatterns:
        """<blockquote>Introduced in BSL v2.15 and firmware v1.16</blockquote> Refer to [Request.GetNamedScanPatterns](#blickfeld.protocol.Request.GetNamedScanPatterns)"""
        pass
    @property
    def store_named_scan_pattern(self) -> global___Request.StoreNamedScanPattern:
        """<blockquote>Introduced in BSL v2.15 and firmware v1.16</blockquote> Refer to [Request.StoreNamedScanPattern](#blickfeld.protocol.Request.StoreNamedScanPattern)"""
        pass
    @property
    def delete_named_scan_pattern(self) -> global___Request.DeleteNamedScanPattern:
        """<blockquote>Introduced in BSL v2.15 and firmware v1.16</blockquote> Refer to [Request.DeleteNamedScanPattern](#blickfeld.protocol.Request.DeleteNamedScanPattern)"""
        pass
    @property
    def proxy_hello(self) -> global___Request.ProxyHello:
        """<blockquote>Introduced in BSL v2.16 and firmware v1.17</blockquote> Refer to [Request.ProxyHello](#blickfeld.protocol.Request.ProxyHello)"""
        pass
    _asJSON: typing.Text = ...
    """Internal use only"""

    accept_format: global___Format.V = ...
    """Internal use only"""

    def __init__(self,
        *,
        hello : typing.Optional[global___Request.Hello] = ...,
        developer : typing.Optional[global___Request.Developer] = ...,
        set_scan_pattern : typing.Optional[global___Request.SetScanPattern] = ...,
        fill_scan_pattern : typing.Optional[global___Request.FillScanPattern] = ...,
        get_scan_pattern : typing.Optional[global___Request.GetScanPattern] = ...,
        subscribe : typing.Optional[blickfeld.stream.connection_pb2.Subscribe] = ...,
        status : typing.Optional[global___Request.Status] = ...,
        run_self_test : typing.Optional[global___Request.RunSelfTest] = ...,
        set_advanced_config : typing.Optional[global___Request.SetAdvancedConfig] = ...,
        get_advanced_config : typing.Optional[global___Request.GetAdvancedConfig] = ...,
        unsubscribe : typing.Optional[blickfeld.stream.connection_pb2.Subscribe] = ...,
        attempt_error_recovery : typing.Optional[global___Request.AttemptErrorRecovery] = ...,
        get_scan_pattern_constraints : typing.Optional[global___Request.GetScanPatternConstraints] = ...,
        get_named_scan_patterns : typing.Optional[global___Request.GetNamedScanPatterns] = ...,
        store_named_scan_pattern : typing.Optional[global___Request.StoreNamedScanPattern] = ...,
        delete_named_scan_pattern : typing.Optional[global___Request.DeleteNamedScanPattern] = ...,
        proxy_hello : typing.Optional[global___Request.ProxyHello] = ...,
        _asJSON : typing.Optional[typing.Text] = ...,
        accept_format : typing.Optional[global___Format.V] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"_asJSON",b"_asJSON",u"accept_format",b"accept_format",u"attempt_error_recovery",b"attempt_error_recovery",u"data",b"data",u"delete_named_scan_pattern",b"delete_named_scan_pattern",u"developer",b"developer",u"fill_scan_pattern",b"fill_scan_pattern",u"get_advanced_config",b"get_advanced_config",u"get_named_scan_patterns",b"get_named_scan_patterns",u"get_scan_pattern",b"get_scan_pattern",u"get_scan_pattern_constraints",b"get_scan_pattern_constraints",u"hello",b"hello",u"proxy_hello",b"proxy_hello",u"run_self_test",b"run_self_test",u"set_advanced_config",b"set_advanced_config",u"set_scan_pattern",b"set_scan_pattern",u"status",b"status",u"store_named_scan_pattern",b"store_named_scan_pattern",u"subscribe",b"subscribe",u"unsubscribe",b"unsubscribe"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"_asJSON",b"_asJSON",u"accept_format",b"accept_format",u"attempt_error_recovery",b"attempt_error_recovery",u"data",b"data",u"delete_named_scan_pattern",b"delete_named_scan_pattern",u"developer",b"developer",u"fill_scan_pattern",b"fill_scan_pattern",u"get_advanced_config",b"get_advanced_config",u"get_named_scan_patterns",b"get_named_scan_patterns",u"get_scan_pattern",b"get_scan_pattern",u"get_scan_pattern_constraints",b"get_scan_pattern_constraints",u"hello",b"hello",u"proxy_hello",b"proxy_hello",u"run_self_test",b"run_self_test",u"set_advanced_config",b"set_advanced_config",u"set_scan_pattern",b"set_scan_pattern",u"status",b"status",u"store_named_scan_pattern",b"store_named_scan_pattern",u"subscribe",b"subscribe",u"unsubscribe",b"unsubscribe"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"data",b"data"]) -> typing.Optional[typing_extensions.Literal["hello","developer","set_scan_pattern","fill_scan_pattern","get_scan_pattern","subscribe","status","run_self_test","set_advanced_config","get_advanced_config","unsubscribe","attempt_error_recovery","get_scan_pattern_constraints","get_named_scan_patterns","store_named_scan_pattern","delete_named_scan_pattern","proxy_hello","_asJSON"]]: ...
global___Request = Request

class Response(google.protobuf.message.Message):
    """*
    This section describes the responses a client receives after sending a request to the server.
    For the request that corresponds to a given response, please refer to [Request](#blickfeld.protocol.Request).
    Each response has the same name as the request.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Hello(google.protobuf.message.Message):
        """*
        This response is sent out after establishing a connection.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Firmware(google.protobuf.message.Message):
            """*
            > Introduced in BSL v2.16 and firmware v1.17

            Contains all firmware names, versions, and revisions.
            """
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            class ModuleVersionsEntry(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
                KEY_FIELD_NUMBER: builtins.int
                VALUE_FIELD_NUMBER: builtins.int
                key: typing.Text = ...
                @property
                def value(self) -> blickfeld.common_pb2.SoftwareVersion: ...
                def __init__(self,
                    *,
                    key : typing.Optional[typing.Text] = ...,
                    value : typing.Optional[blickfeld.common_pb2.SoftwareVersion] = ...,
                    ) -> None: ...
                def HasField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

            VERSION_FIELD_NUMBER: builtins.int
            MODULE_VERSIONS_FIELD_NUMBER: builtins.int
            @property
            def version(self) -> blickfeld.common_pb2.SoftwareVersion:
                """Baseline version of firmware. Refer to [SoftwareVersion](#blickfeld.protocol.SoftwareVersion)."""
                pass
            @property
            def module_versions(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, blickfeld.common_pb2.SoftwareVersion]:
                """Version of software modules. The key of the map is the name and the object is the [SoftwareVersion](#blickfeld.protocol.SoftwareVersion)."""
                pass
            def __init__(self,
                *,
                version : typing.Optional[blickfeld.common_pb2.SoftwareVersion] = ...,
                module_versions : typing.Optional[typing.Mapping[typing.Text, blickfeld.common_pb2.SoftwareVersion]] = ...,
                ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal[u"version",b"version"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"module_versions",b"module_versions",u"version",b"version"]) -> None: ...

        class HardwareModulesEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: typing.Text = ...
            @property
            def value(self) -> blickfeld.common_pb2.HardwareModule: ...
            def __init__(self,
                *,
                key : typing.Optional[typing.Text] = ...,
                value : typing.Optional[blickfeld.common_pb2.HardwareModule] = ...,
                ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

        PROTOCOL_VERSION_FIELD_NUMBER: builtins.int
        LIBRARY_VERSION_FIELD_NUMBER: builtins.int
        LANGUAGE_FIELD_NUMBER: builtins.int
        PRODUCT_FIELD_NUMBER: builtins.int
        SERIAL_NUMBER_FIELD_NUMBER: builtins.int
        LEGACY_SERIAL_NUMBER_FIELD_NUMBER: builtins.int
        FIRMWARE_FIELD_NUMBER: builtins.int
        HARDWARE_MODULES_FIELD_NUMBER: builtins.int
        protocol_version: builtins.int = ...
        """Version of the Blickfeld Protocol"""

        library_version: typing.Text = ...
        """<blockquote>Introduced in BSL v2.16 and firmware v1.17</blockquote> Library version"""

        language: blickfeld.common_pb2.Language.V = ...
        """<blockquote>Introduced in BSL v2.16 and firmware v1.17</blockquote> Library language"""

        product: blickfeld.config.product_pb2.Product.V = ...
        """<blockquote>Introduced in BSL v2.16 and firmware v1.17</blockquote> Refer to [Product](#blickfeld.protocol.config.Product)."""

        serial_number: typing.Text = ...
        """<blockquote>Introduced in BSL v2.16 and firmware v1.17</blockquote> Cube serial number"""

        legacy_serial_number: typing.Text = ...
        """<blockquote>Introduced in BSL v2.16 and firmware v1.17</blockquote> Deprecated legacy serial number"""

        @property
        def firmware(self) -> global___Response.Hello.Firmware:
            """<blockquote>Introduced in BSL v2.16 and firmware v1.17</blockquote> Refer to [Firmware](#blickfeld.protocol.Response.Hello.Firmware)."""
            pass
        @property
        def hardware_modules(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, blickfeld.common_pb2.HardwareModule]:
            """<blockquote>Introduced in BSL v2.16 and firmware v1.17</blockquote> Hardware module map, where the key is the name and the object is the [HardwareModule](#blickfeld.protocol.HardwareModule)."""
            pass
        def __init__(self,
            *,
            protocol_version : typing.Optional[builtins.int] = ...,
            library_version : typing.Optional[typing.Text] = ...,
            language : typing.Optional[blickfeld.common_pb2.Language.V] = ...,
            product : typing.Optional[blickfeld.config.product_pb2.Product.V] = ...,
            serial_number : typing.Optional[typing.Text] = ...,
            legacy_serial_number : typing.Optional[typing.Text] = ...,
            firmware : typing.Optional[global___Response.Hello.Firmware] = ...,
            hardware_modules : typing.Optional[typing.Mapping[typing.Text, blickfeld.common_pb2.HardwareModule]] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"firmware",b"firmware",u"language",b"language",u"legacy_serial_number",b"legacy_serial_number",u"library_version",b"library_version",u"oneof_serial_number",b"oneof_serial_number",u"product",b"product",u"protocol_version",b"protocol_version",u"serial_number",b"serial_number"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"firmware",b"firmware",u"hardware_modules",b"hardware_modules",u"language",b"language",u"legacy_serial_number",b"legacy_serial_number",u"library_version",b"library_version",u"oneof_serial_number",b"oneof_serial_number",u"product",b"product",u"protocol_version",b"protocol_version",u"serial_number",b"serial_number"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal[u"oneof_serial_number",b"oneof_serial_number"]) -> typing.Optional[typing_extensions.Literal["serial_number","legacy_serial_number"]]: ...

    class ProxyHello(google.protobuf.message.Message):
        """*
        Internal use only
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class Developer(google.protobuf.message.Message):
        """*
        Internal use only
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class SetScanPattern(google.protobuf.message.Message):
        """*
        This response is sent out after setting a scan pattern.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class FillScanPattern(google.protobuf.message.Message):
        """*
        This response is given after a request to fill a sparse [ScanPattern](#blickfeld.protocol.config.ScanPattern) has been transmitted.
        It returns a scan pattern, the unset fields are filled with default values.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CONFIG_FIELD_NUMBER: builtins.int
        @property
        def config(self) -> blickfeld.config.scan_pattern_pb2.ScanPattern:
            """Refer to [ScanPattern](#blickfeld.protocol.config.ScanPattern)"""
            pass
        def __init__(self,
            *,
            config : typing.Optional[blickfeld.config.scan_pattern_pb2.ScanPattern] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"config",b"config"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"config",b"config"]) -> None: ...

    class GetScanPattern(google.protobuf.message.Message):
        """*
        This response is returned after a request to get the current [ScanPattern](#blickfeld.protocol.config.ScanPattern).
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CONFIG_FIELD_NUMBER: builtins.int
        @property
        def config(self) -> blickfeld.config.scan_pattern_pb2.ScanPattern:
            """Refer to [ScanPattern](#blickfeld.protocol.config.ScanPattern)"""
            pass
        def __init__(self,
            *,
            config : typing.Optional[blickfeld.config.scan_pattern_pb2.ScanPattern] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"config",b"config"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"config",b"config"]) -> None: ...

    class RunSelfTest(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.10 and firmware v1.9

        This response is returned after a self test.
        The success flag indicates if the hardware is fully operational.
        The generated report is currently only accessible by developers.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        SUCCESS_FIELD_NUMBER: builtins.int
        success: builtins.bool = ...
        def __init__(self,
            *,
            success : typing.Optional[builtins.bool] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"success",b"success"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"success",b"success"]) -> None: ...

    class SetAdvancedConfig(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.11 and firmware v1.11

        This response is sent out after setting an SetAdvancedConfig.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class GetAdvancedConfig(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.11 and firmware v1.11

        This response is returned after a request to get the current [Advanced](#blickfeld.protocol.config.Advanced).
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CONFIG_FIELD_NUMBER: builtins.int
        @property
        def config(self) -> blickfeld.config.advanced_pb2.Advanced:
            """Refer to [Advanced](#blickfeld.protocol.config.Advanced)"""
            pass
        def __init__(self,
            *,
            config : typing.Optional[blickfeld.config.advanced_pb2.Advanced] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"config",b"config"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"config",b"config"]) -> None: ...

    class AttemptErrorRecovery(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.13 and firmware v1.13

        This response is sent out after sending AttemptErrorRecovery.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class GetScanPatternConstraints(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.14 and firmware v1.14

        This response is sent out after sending GetScanPatternConstraints.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CONSTRAINTS_FIELD_NUMBER: builtins.int
        @property
        def constraints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[blickfeld.common_pb2.Constraint]:
            """List of constraints which apply for scan patterns."""
            pass
        def __init__(self,
            *,
            constraints : typing.Optional[typing.Iterable[blickfeld.common_pb2.Constraint]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"constraints",b"constraints"]) -> None: ...

    class GetNamedScanPatterns(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.15 and firmware v1.16

        This response is sent out after sending GetNamedScanPatterns.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CONFIGS_FIELD_NUMBER: builtins.int
        @property
        def configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[blickfeld.config.named_scan_pattern_pb2.NamedScanPattern]:
            """List of named scan patterns, refer to [NamedScanPattern](#blickfeld.protocol.config.NamedScanPattern)"""
            pass
        def __init__(self,
            *,
            configs : typing.Optional[typing.Iterable[blickfeld.config.named_scan_pattern_pb2.NamedScanPattern]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"configs",b"configs"]) -> None: ...

    class StoreNamedScanPattern(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.15 and firmware v1.16

        This response is sent out after sending StoreNamedScanPattern.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class DeleteNamedScanPattern(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.15 and firmware v1.16

        This response is sent out after sending DeleteNamedScanPattern.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    TIMESTAMP_NS_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    HELLO_FIELD_NUMBER: builtins.int
    DEVELOPER_FIELD_NUMBER: builtins.int
    SET_SCAN_PATTERN_FIELD_NUMBER: builtins.int
    FILL_SCAN_PATTERN_FIELD_NUMBER: builtins.int
    GET_SCAN_PATTERN_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RUN_SELF_TEST_FIELD_NUMBER: builtins.int
    SET_ADVANCED_CONFIG_FIELD_NUMBER: builtins.int
    GET_ADVANCED_CONFIG_FIELD_NUMBER: builtins.int
    ATTEMPT_ERROR_RECOVERY_FIELD_NUMBER: builtins.int
    GET_SCAN_PATTERN_CONSTRAINTS_FIELD_NUMBER: builtins.int
    GET_NAMED_SCAN_PATTERNS_FIELD_NUMBER: builtins.int
    STORE_NAMED_SCAN_PATTERN_FIELD_NUMBER: builtins.int
    DELETE_NAMED_SCAN_PATTERN_FIELD_NUMBER: builtins.int
    PROXY_HELLO_FIELD_NUMBER: builtins.int
    _ASJSON_FIELD_NUMBER: builtins.int
    timestamp_ns: builtins.int = ...
    """Unit: [ns] - timestamp when the response is sent out"""

    @property
    def error(self) -> blickfeld.error_pb2.Error:
        """Refer to [Error](#blickfeld.protocol.Error)"""
        pass
    @property
    def hello(self) -> global___Response.Hello:
        """Refer to [Response.Hello](#blickfeld.protocol.Response.Hello)"""
        pass
    @property
    def developer(self) -> global___Response.Developer:
        """Refer to [Response.Developer](#blickfeld.protocol.Response.Developer)"""
        pass
    @property
    def set_scan_pattern(self) -> global___Response.SetScanPattern:
        """Refer to [Response.SetScanPattern](#blickfeld.protocol.Response.SetScanPattern)"""
        pass
    @property
    def fill_scan_pattern(self) -> global___Response.FillScanPattern:
        """Refer to [Response.FillScanPattern](#blickfeld.protocol.Response.FillScanPattern)"""
        pass
    @property
    def get_scan_pattern(self) -> global___Response.GetScanPattern:
        """Refer to [Response.GetScanPattern](#blickfeld.protocol.Response.GetScanPattern)"""
        pass
    @property
    def event(self) -> blickfeld.stream.event_pb2.Event:
        """Refer to [Event](#blickfeld.protocol.stream.Event)"""
        pass
    @property
    def status(self) -> blickfeld.status.main_pb2.Status:
        """Refer to [Response.Status](#blickfeld.protocol.Response.Status)"""
        pass
    @property
    def run_self_test(self) -> global___Response.RunSelfTest:
        """Refer to [Response.RunSelfTest](#blickfeld.protocol.Response.RunSelfTest)"""
        pass
    @property
    def set_advanced_config(self) -> global___Response.SetAdvancedConfig:
        """<blockquote>Introduced in BSL v2.11 and firmware v1.11</blockquote> Refer to [Response.SetAdvanced](#blickfeld.protocol.Response.SetAdvancedConfig)"""
        pass
    @property
    def get_advanced_config(self) -> global___Response.GetAdvancedConfig:
        """<blockquote>Introduced in BSL v2.11 and firmware v1.11</blockquote> Refer to [Response.GetAdvanced](#blickfeld.protocol.Response.GetAdvancedConfig)"""
        pass
    @property
    def attempt_error_recovery(self) -> global___Response.AttemptErrorRecovery:
        """<blockquote>Introduced in BSL v2.13 and firmware v1.13</blockquote> Refer to [Response.AttemptErrorRecovery](#blickfeld.protocol.Response.AttemptErrorRecovery)"""
        pass
    @property
    def get_scan_pattern_constraints(self) -> global___Response.GetScanPatternConstraints:
        """<blockquote>Introduced in BSL v2.14 and firmware v1.14</blockquote> Refer to [Response.GetScanPatternConstraints](#blickfeld.protocol.Response.GetScanPatternConstraints)"""
        pass
    @property
    def get_named_scan_patterns(self) -> global___Response.GetNamedScanPatterns:
        """<blockquote>Introduced in BSL v2.15 and firmware v1.16</blockquote> Refer to [Response.GetNamedScanPatterns](#blickfeld.protocol.Response.GetNamedScanPatterns)"""
        pass
    @property
    def store_named_scan_pattern(self) -> global___Response.StoreNamedScanPattern:
        """<blockquote>Introduced in BSL v2.15 and firmware v1.16</blockquote> Refer to [Response.StoreNamedScanPattern](#blickfeld.protocol.Response.StoreNamedScanPattern)"""
        pass
    @property
    def delete_named_scan_pattern(self) -> global___Response.DeleteNamedScanPattern:
        """<blockquote>Introduced in BSL v2.15 and firmware v1.16</blockquote> Refer to [Response.DeleteNamedScanPattern](#blickfeld.protocol.Response.DeleteNamedScanPattern)"""
        pass
    @property
    def proxy_hello(self) -> global___Response.ProxyHello:
        """<blockquote>Introduced in BSL v2.16 and firmware v1.17</blockquote> Refer to [Response.ProxyHello](#blickfeld.protocol.Response.ProxyHello)"""
        pass
    _asJSON: typing.Text = ...
    """Internal use only"""

    def __init__(self,
        *,
        timestamp_ns : typing.Optional[builtins.int] = ...,
        error : typing.Optional[blickfeld.error_pb2.Error] = ...,
        hello : typing.Optional[global___Response.Hello] = ...,
        developer : typing.Optional[global___Response.Developer] = ...,
        set_scan_pattern : typing.Optional[global___Response.SetScanPattern] = ...,
        fill_scan_pattern : typing.Optional[global___Response.FillScanPattern] = ...,
        get_scan_pattern : typing.Optional[global___Response.GetScanPattern] = ...,
        event : typing.Optional[blickfeld.stream.event_pb2.Event] = ...,
        status : typing.Optional[blickfeld.status.main_pb2.Status] = ...,
        run_self_test : typing.Optional[global___Response.RunSelfTest] = ...,
        set_advanced_config : typing.Optional[global___Response.SetAdvancedConfig] = ...,
        get_advanced_config : typing.Optional[global___Response.GetAdvancedConfig] = ...,
        attempt_error_recovery : typing.Optional[global___Response.AttemptErrorRecovery] = ...,
        get_scan_pattern_constraints : typing.Optional[global___Response.GetScanPatternConstraints] = ...,
        get_named_scan_patterns : typing.Optional[global___Response.GetNamedScanPatterns] = ...,
        store_named_scan_pattern : typing.Optional[global___Response.StoreNamedScanPattern] = ...,
        delete_named_scan_pattern : typing.Optional[global___Response.DeleteNamedScanPattern] = ...,
        proxy_hello : typing.Optional[global___Response.ProxyHello] = ...,
        _asJSON : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"_asJSON",b"_asJSON",u"attempt_error_recovery",b"attempt_error_recovery",u"data",b"data",u"delete_named_scan_pattern",b"delete_named_scan_pattern",u"developer",b"developer",u"error",b"error",u"event",b"event",u"fill_scan_pattern",b"fill_scan_pattern",u"get_advanced_config",b"get_advanced_config",u"get_named_scan_patterns",b"get_named_scan_patterns",u"get_scan_pattern",b"get_scan_pattern",u"get_scan_pattern_constraints",b"get_scan_pattern_constraints",u"hello",b"hello",u"proxy_hello",b"proxy_hello",u"run_self_test",b"run_self_test",u"set_advanced_config",b"set_advanced_config",u"set_scan_pattern",b"set_scan_pattern",u"status",b"status",u"store_named_scan_pattern",b"store_named_scan_pattern",u"timestamp_ns",b"timestamp_ns"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"_asJSON",b"_asJSON",u"attempt_error_recovery",b"attempt_error_recovery",u"data",b"data",u"delete_named_scan_pattern",b"delete_named_scan_pattern",u"developer",b"developer",u"error",b"error",u"event",b"event",u"fill_scan_pattern",b"fill_scan_pattern",u"get_advanced_config",b"get_advanced_config",u"get_named_scan_patterns",b"get_named_scan_patterns",u"get_scan_pattern",b"get_scan_pattern",u"get_scan_pattern_constraints",b"get_scan_pattern_constraints",u"hello",b"hello",u"proxy_hello",b"proxy_hello",u"run_self_test",b"run_self_test",u"set_advanced_config",b"set_advanced_config",u"set_scan_pattern",b"set_scan_pattern",u"status",b"status",u"store_named_scan_pattern",b"store_named_scan_pattern",u"timestamp_ns",b"timestamp_ns"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"data",b"data"]) -> typing.Optional[typing_extensions.Literal["error","hello","developer","set_scan_pattern","fill_scan_pattern","get_scan_pattern","event","status","run_self_test","set_advanced_config","get_advanced_config","attempt_error_recovery","get_scan_pattern_constraints","get_named_scan_patterns","store_named_scan_pattern","delete_named_scan_pattern","proxy_hello","_asJSON"]]: ...
global___Response = Response



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bf_proto.percept.common.geometric_shapes_pb2
import bf_proto.percept.common.geometry_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ZoneAlgorithm(google.protobuf.message.Message):
    """*
    An algorithm that performs a set of instructions.
    Algorithm binds a name and a set of internal states to a zone.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class CurrentObjectsCounter(google.protobuf.message.Message):
        """*
        Algorithm that counts the number of objects in a zone.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class PassThroughCounter(google.protobuf.message.Message):
        """*
        Algorithm that counts the number of objects entering or exiting a zone.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        INBOUND_FIELD_NUMBER: builtins.int
        ACCUMULATE_COUNT_FIELD_NUMBER: builtins.int
        @property
        def inbound(self) -> bf_proto.percept.common.geometry_pb2.Axis:
            """The Inbound Direction, that is defined by the axis of"""
            pass
        accumulate_count: builtins.bool = ...
        """the zone's pose.
        If the count in entry/exit directions is accumulated or not.
        """

        def __init__(self,
            *,
            inbound : typing.Optional[bf_proto.percept.common.geometry_pb2.Axis] = ...,
            accumulate_count : builtins.bool = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"inbound",b"inbound"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"accumulate_count",b"accumulate_count",u"inbound",b"inbound"]) -> None: ...

    class AppearanceDisappearanceCounter(google.protobuf.message.Message):
        """*
        Algorithm that counts the number of objects appearing or disappearing
        in a zone.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ACCUMULATE_COUNT_FIELD_NUMBER: builtins.int
        accumulate_count: builtins.bool = ...
        """If the count in the two directions is accumulated or not."""

        def __init__(self,
            *,
            accumulate_count : builtins.bool = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"accumulate_count",b"accumulate_count"]) -> None: ...

    class Security(google.protobuf.message.Message):
        """*
        Algorithm that triggers an alarm if movement was detected in the zone
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        MIN_POINTS_FIELD_NUMBER: builtins.int
        min_points: builtins.int = ...
        """Minimum number of points in a security zone to trigger the detection. Default: 10"""

        def __init__(self,
            *,
            min_points : builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"min_points",b"min_points"]) -> None: ...

    class Occupancy(google.protobuf.message.Message):
        """*
        Algorithm that detectes if a zone is occupied
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        MIN_POINTS_FIELD_NUMBER: builtins.int
        min_points: builtins.int = ...
        """Minimum number of points in a occupancy zone to trigger the detection. Default: 10"""

        def __init__(self,
            *,
            min_points : builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"min_points",b"min_points"]) -> None: ...

    class Volume(google.protobuf.message.Message):
        """*
        Algorithm that measure the volume of a zone
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        RESOLUTION_FIELD_NUMBER: builtins.int
        EMPTY_VOLUME_FIELD_NUMBER: builtins.int
        resolution: builtins.float = ...
        """Grid resolution per tile used to measure the volume. Default: 0.1"""

        empty_volume: builtins.float = ...
        """Empty Volume of the scene, this is substracted from the measured volume to get the"""

        def __init__(self,
            *,
            resolution : builtins.float = ...,
            empty_volume : builtins.float = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"empty_volume",b"empty_volume",u"resolution",b"resolution"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    UUID_FIELD_NUMBER: builtins.int
    SHAPE_FIELD_NUMBER: builtins.int
    CURRENT_OBJECTS_COUNTER_FIELD_NUMBER: builtins.int
    PASS_THROUGH_COUNTER_FIELD_NUMBER: builtins.int
    APPEARANCE_DISAPPEARANCE_COUNTER_FIELD_NUMBER: builtins.int
    SECURITY_FIELD_NUMBER: builtins.int
    OCCUPANCY_FIELD_NUMBER: builtins.int
    VOLUME_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    """Zone Algorithm name."""

    uuid: typing.Text = ...
    """Zone Algorithm UUID."""

    @property
    def shape(self) -> bf_proto.percept.common.geometric_shapes_pb2.Shape:
        """Geometric shape (usually a Box) in which the algorithm detects certain behaviors/scenarios."""
        pass
    @property
    def current_objects_counter(self) -> global___ZoneAlgorithm.CurrentObjectsCounter: ...
    @property
    def pass_through_counter(self) -> global___ZoneAlgorithm.PassThroughCounter: ...
    @property
    def appearance_disappearance_counter(self) -> global___ZoneAlgorithm.AppearanceDisappearanceCounter: ...
    @property
    def security(self) -> global___ZoneAlgorithm.Security: ...
    @property
    def occupancy(self) -> global___ZoneAlgorithm.Occupancy: ...
    @property
    def volume(self) -> global___ZoneAlgorithm.Volume: ...
    def __init__(self,
        *,
        name : typing.Text = ...,
        uuid : typing.Text = ...,
        shape : typing.Optional[bf_proto.percept.common.geometric_shapes_pb2.Shape] = ...,
        current_objects_counter : typing.Optional[global___ZoneAlgorithm.CurrentObjectsCounter] = ...,
        pass_through_counter : typing.Optional[global___ZoneAlgorithm.PassThroughCounter] = ...,
        appearance_disappearance_counter : typing.Optional[global___ZoneAlgorithm.AppearanceDisappearanceCounter] = ...,
        security : typing.Optional[global___ZoneAlgorithm.Security] = ...,
        occupancy : typing.Optional[global___ZoneAlgorithm.Occupancy] = ...,
        volume : typing.Optional[global___ZoneAlgorithm.Volume] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"algorithm_type",b"algorithm_type",u"appearance_disappearance_counter",b"appearance_disappearance_counter",u"current_objects_counter",b"current_objects_counter",u"occupancy",b"occupancy",u"pass_through_counter",b"pass_through_counter",u"security",b"security",u"shape",b"shape",u"volume",b"volume"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"algorithm_type",b"algorithm_type",u"appearance_disappearance_counter",b"appearance_disappearance_counter",u"current_objects_counter",b"current_objects_counter",u"name",b"name",u"occupancy",b"occupancy",u"pass_through_counter",b"pass_through_counter",u"security",b"security",u"shape",b"shape",u"uuid",b"uuid",u"volume",b"volume"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"algorithm_type",b"algorithm_type"]) -> typing.Optional[typing_extensions.Literal["current_objects_counter","pass_through_counter","appearance_disappearance_counter","security","occupancy","volume"]]: ...
global___ZoneAlgorithm = ZoneAlgorithm



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bf_proto/percept/common/geometric_shapes.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bf_proto.percept.common import geometry_pb2 as bf__proto_dot_percept_dot_common_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='bf_proto/percept/common/geometric_shapes.proto',
  package='blickfeld.percept.common',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.bf_proto/percept/common/geometric_shapes.proto\x12\x18\x62lickfeld.percept.common\x1a&bf_proto/percept/common/geometry.proto\"\xb5\x01\n\x05Shape\x12,\n\x04pose\x18\x01 \x01(\x0b\x32\x1e.blickfeld.percept.common.Pose\x12\x32\n\x03\x62ox\x18\x02 \x01(\x0b\x32#.blickfeld.percept.common.Shape.BoxH\x00\x1a<\n\x03\x42ox\x12\x35\n\ndimensions\x18\x01 \x01(\x0b\x32!.blickfeld.percept.common.Vector3B\x0c\n\nshape_typeb\x06proto3'
  ,
  dependencies=[bf__proto_dot_percept_dot_common_dot_geometry__pb2.DESCRIPTOR,])




_SHAPE_BOX = _descriptor.Descriptor(
  name='Box',
  full_name='blickfeld.percept.common.Shape.Box',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dimensions', full_name='blickfeld.percept.common.Shape.Box.dimensions', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=284,
)

_SHAPE = _descriptor.Descriptor(
  name='Shape',
  full_name='blickfeld.percept.common.Shape',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='blickfeld.percept.common.Shape.pose', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='box', full_name='blickfeld.percept.common.Shape.box', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SHAPE_BOX, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='shape_type', full_name='blickfeld.percept.common.Shape.shape_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=117,
  serialized_end=298,
)

_SHAPE_BOX.fields_by_name['dimensions'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._VECTOR3
_SHAPE_BOX.containing_type = _SHAPE
_SHAPE.fields_by_name['pose'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._POSE
_SHAPE.fields_by_name['box'].message_type = _SHAPE_BOX
_SHAPE.oneofs_by_name['shape_type'].fields.append(
  _SHAPE.fields_by_name['box'])
_SHAPE.fields_by_name['box'].containing_oneof = _SHAPE.oneofs_by_name['shape_type']
DESCRIPTOR.message_types_by_name['Shape'] = _SHAPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Shape = _reflection.GeneratedProtocolMessageType('Shape', (_message.Message,), {

  'Box' : _reflection.GeneratedProtocolMessageType('Box', (_message.Message,), {
    'DESCRIPTOR' : _SHAPE_BOX,
    '__module__' : 'bf_proto.percept.common.geometric_shapes_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.common.Shape.Box)
    })
  ,
  'DESCRIPTOR' : _SHAPE,
  '__module__' : 'bf_proto.percept.common.geometric_shapes_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.common.Shape)
  })
_sym_db.RegisterMessage(Shape)
_sym_db.RegisterMessage(Shape.Box)


# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.update.hardware_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class manifest_msg(google.protobuf.message.Message):
    """WARNING: only proto3 features are supported for JSON serialization
    WARNING: do NOT change enum labels, they are used as strings in code

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class ImageType(_ImageType, metaclass=_ImageTypeEnumTypeWrapper):
        pass
    class _ImageType:
        V = typing.NewType('V', builtins.int)
    class _ImageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ImageType.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        PARTITIONED = manifest_msg.ImageType.V(0)
        SYSTEM = manifest_msg.ImageType.V(1)

    PARTITIONED = manifest_msg.ImageType.V(0)
    SYSTEM = manifest_msg.ImageType.V(1)

    class CompatibleHardware(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        VARIANT_FIELD_NUMBER: builtins.int
        MSB_FIELD_NUMBER: builtins.int
        SCANNER_BIG_FIELD_NUMBER: builtins.int
        SCANNER_SMALL_FIELD_NUMBER: builtins.int
        HSD_FIELD_NUMBER: builtins.int
        @property
        def variant(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[blickfeld.update.hardware_pb2.HardwareVariant.V]: ...
        @property
        def msb(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
        @property
        def scanner_big(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
        @property
        def scanner_small(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
        @property
        def hsd(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
        def __init__(self,
            *,
            variant : typing.Optional[typing.Iterable[blickfeld.update.hardware_pb2.HardwareVariant.V]] = ...,
            msb : typing.Optional[typing.Iterable[typing.Text]] = ...,
            scanner_big : typing.Optional[typing.Iterable[typing.Text]] = ...,
            scanner_small : typing.Optional[typing.Iterable[typing.Text]] = ...,
            hsd : typing.Optional[typing.Iterable[typing.Text]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"hsd",b"hsd",u"msb",b"msb",u"scanner_big",b"scanner_big",u"scanner_small",b"scanner_small",u"variant",b"variant"]) -> None: ...

    MIN_BUS_VERSION_FIELD_NUMBER: builtins.int
    IMAGE_TYPE_FIELD_NUMBER: builtins.int
    COMPATIBLE_HARDWARE_FIELD_NUMBER: builtins.int
    SECURE_FIELD_NUMBER: builtins.int
    min_bus_version: typing.Text = ...
    image_type: global___manifest_msg.ImageType.V = ...
    @property
    def compatible_hardware(self) -> global___manifest_msg.CompatibleHardware: ...
    secure: builtins.bool = ...
    def __init__(self,
        *,
        min_bus_version : typing.Optional[typing.Text] = ...,
        image_type : typing.Optional[global___manifest_msg.ImageType.V] = ...,
        compatible_hardware : typing.Optional[global___manifest_msg.CompatibleHardware] = ...,
        secure : typing.Optional[builtins.bool] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"compatible_hardware",b"compatible_hardware",u"image_type",b"image_type",u"min_bus_version",b"min_bus_version",u"secure",b"secure"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"compatible_hardware",b"compatible_hardware",u"image_type",b"image_type",u"min_bus_version",b"min_bus_version",u"secure",b"secure"]) -> None: ...
global___manifest_msg = manifest_msg



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.data.point_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Scanline(google.protobuf.message.Message):
    """*
    This section describes the contents of a single scan line in a point cloud frame.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ID_FIELD_NUMBER: builtins.int
    FRAME_ID_FIELD_NUMBER: builtins.int
    POINTS_FIELD_NUMBER: builtins.int
    START_OFFSET_NS_FIELD_NUMBER: builtins.int
    id: builtins.int = ...
    """Scan line ID in the corresponding frame"""

    frame_id: builtins.int = ...
    """Frame ID of the corresponding frame"""

    @property
    def points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[blickfeld.data.point_pb2.Point]:
        """Refer to [Point](#blickfeld.protocol.data.Point)"""
        pass
    start_offset_ns: builtins.int = ...
    """Unit: [ns] - start time of the scanline in relation to [Frame.start_time_ns](#blickfeld.protocol.data.Frame.start_time_ns)"""

    def __init__(self,
        *,
        id : typing.Optional[builtins.int] = ...,
        frame_id : typing.Optional[builtins.int] = ...,
        points : typing.Optional[typing.Iterable[blickfeld.data.point_pb2.Point]] = ...,
        start_offset_ns : typing.Optional[builtins.int] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"frame_id",b"frame_id",u"id",b"id",u"start_offset_ns",b"start_offset_ns"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"frame_id",b"frame_id",u"id",b"id",u"points",b"points",u"start_offset_ns",b"start_offset_ns"]) -> None: ...
global___Scanline = Scanline



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bf_proto.percept.output.output_pb2
import blickfeld.data.frame_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LaserName(_LaserName, metaclass=_LaserNameEnumTypeWrapper):
    """Laser identifier"""
    pass
class _LaserName:
    V = typing.NewType('V', builtins.int)
class _LaserNameEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LaserName.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    LASER_NAME_UNKNOWN = LaserName.V(0)
    FRONT = LaserName.V(1)
    MIDDLE = LaserName.V(2)
    BACK = LaserName.V(3)

LASER_NAME_UNKNOWN = LaserName.V(0)
FRONT = LaserName.V(1)
MIDDLE = LaserName.V(2)
BACK = LaserName.V(3)
global___LaserName = LaserName


class Transform(google.protobuf.message.Message):
    """4×4 row-major transform matrix"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MATRIX_FIELD_NUMBER: builtins.int
    @property
    def matrix(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(self,
        *,
        matrix : typing.Optional[typing.Iterable[builtins.float]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"matrix",b"matrix"]) -> None: ...
global___Transform = Transform

class LaserCalibration(google.protobuf.message.Message):
    """Container for laser calibration parameters"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXTRINSIC_FIELD_NUMBER: builtins.int
    VERTICAL_FOV_FIELD_NUMBER: builtins.int
    HORIZONTAL_FOV_FIELD_NUMBER: builtins.int
    HORIZONTAL_ANGLE_SPACING_FIELD_NUMBER: builtins.int
    FRAME_MODE_FIELD_NUMBER: builtins.int
    SCAN_PATTERN_FIELD_NUMBER: builtins.int
    @property
    def extrinsic(self) -> global___Transform: ...
    vertical_fov: builtins.float = ...
    horizontal_fov: builtins.float = ...
    horizontal_angle_spacing: builtins.float = ...
    frame_mode: typing.Text = ...
    scan_pattern: typing.Text = ...
    def __init__(self,
        *,
        extrinsic : typing.Optional[global___Transform] = ...,
        vertical_fov : typing.Optional[builtins.float] = ...,
        horizontal_fov : typing.Optional[builtins.float] = ...,
        horizontal_angle_spacing : typing.Optional[builtins.float] = ...,
        frame_mode : typing.Optional[typing.Text] = ...,
        scan_pattern : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"extrinsic",b"extrinsic",u"frame_mode",b"frame_mode",u"horizontal_angle_spacing",b"horizontal_angle_spacing",u"horizontal_fov",b"horizontal_fov",u"scan_pattern",b"scan_pattern",u"vertical_fov",b"vertical_fov"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"extrinsic",b"extrinsic",u"frame_mode",b"frame_mode",u"horizontal_angle_spacing",b"horizontal_angle_spacing",u"horizontal_fov",b"horizontal_fov",u"scan_pattern",b"scan_pattern",u"vertical_fov",b"vertical_fov"]) -> None: ...
global___LaserCalibration = LaserCalibration

class Laser(google.protobuf.message.Message):
    """Single LiDAR sensor with its data"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LASER_NAME_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    CALIBRATION_FIELD_NUMBER: builtins.int
    laser_name: global___LaserName.V = ...
    @property
    def data(self) -> blickfeld.data.frame_pb2.Frame: ...
    @property
    def calibration(self) -> global___LaserCalibration: ...
    def __init__(self,
        *,
        laser_name : typing.Optional[global___LaserName.V] = ...,
        data : typing.Optional[blickfeld.data.frame_pb2.Frame] = ...,
        calibration : typing.Optional[global___LaserCalibration] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"calibration",b"calibration",u"data",b"data",u"laser_name",b"laser_name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"calibration",b"calibration",u"data",b"data",u"laser_name",b"laser_name"]) -> None: ...
global___Laser = Laser

class Frame(google.protobuf.message.Message):
    """Snapshot of all sensors at a given time, plus detected objects"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TIMESTAMP_NS_FIELD_NUMBER: builtins.int
    LASERS_FIELD_NUMBER: builtins.int
    OBJECT_LIST_FIELD_NUMBER: builtins.int
    timestamp_ns: builtins.int = ...
    @property
    def lasers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Laser]: ...
    @property
    def object_list(self) -> bf_proto.percept.output.output_pb2.ObjectList: ...
    def __init__(self,
        *,
        timestamp_ns : typing.Optional[builtins.int] = ...,
        lasers : typing.Optional[typing.Iterable[global___Laser]] = ...,
        object_list : typing.Optional[bf_proto.percept.output.output_pb2.ObjectList] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"object_list",b"object_list",u"timestamp_ns",b"timestamp_ns"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"lasers",b"lasers",u"object_list",b"object_list",u"timestamp_ns",b"timestamp_ns"]) -> None: ...
global___Frame = Frame



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bf_proto/percept/common/geometry.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='bf_proto/percept/common/geometry.proto',
  package='blickfeld.percept.common',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&bf_proto/percept/common/geometry.proto\x12\x18\x62lickfeld.percept.common\"V\n\x04\x41xis\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.blickfeld.percept.common.Axis.Type\"\x1b\n\x04Type\x12\x05\n\x01X\x10\x00\x12\x05\n\x01Y\x10\x01\x12\x05\n\x01Z\x10\x02\"*\n\x07Vector3\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"8\n\nQuaternion\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x12\t\n\x01w\x18\x04 \x01(\x02\"v\n\x04Pose\x12\x33\n\x08position\x18\x01 \x01(\x0b\x32!.blickfeld.percept.common.Vector3\x12\x39\n\x0borientation\x18\x02 \x01(\x0b\x32$.blickfeld.percept.common.Quaternion\"{\n\tTransform\x12\x36\n\x0btranslation\x18\x01 \x01(\x0b\x32!.blickfeld.percept.common.Vector3\x12\x36\n\x08rotation\x18\x02 \x01(\x0b\x32$.blickfeld.percept.common.Quaternionb\x06proto3'
)



_AXIS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='blickfeld.percept.common.Axis.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='X', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Y', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Z', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=127,
  serialized_end=154,
)
_sym_db.RegisterEnumDescriptor(_AXIS_TYPE)


_AXIS = _descriptor.Descriptor(
  name='Axis',
  full_name='blickfeld.percept.common.Axis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='blickfeld.percept.common.Axis.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AXIS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=154,
)


_VECTOR3 = _descriptor.Descriptor(
  name='Vector3',
  full_name='blickfeld.percept.common.Vector3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='blickfeld.percept.common.Vector3.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='blickfeld.percept.common.Vector3.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='blickfeld.percept.common.Vector3.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=198,
)


_QUATERNION = _descriptor.Descriptor(
  name='Quaternion',
  full_name='blickfeld.percept.common.Quaternion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='blickfeld.percept.common.Quaternion.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='blickfeld.percept.common.Quaternion.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='blickfeld.percept.common.Quaternion.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='w', full_name='blickfeld.percept.common.Quaternion.w', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=256,
)


_POSE = _descriptor.Descriptor(
  name='Pose',
  full_name='blickfeld.percept.common.Pose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='blickfeld.percept.common.Pose.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='blickfeld.percept.common.Pose.orientation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=258,
  serialized_end=376,
)


_TRANSFORM = _descriptor.Descriptor(
  name='Transform',
  full_name='blickfeld.percept.common.Transform',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='translation', full_name='blickfeld.percept.common.Transform.translation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='blickfeld.percept.common.Transform.rotation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=501,
)

_AXIS.fields_by_name['type'].enum_type = _AXIS_TYPE
_AXIS_TYPE.containing_type = _AXIS
_POSE.fields_by_name['position'].message_type = _VECTOR3
_POSE.fields_by_name['orientation'].message_type = _QUATERNION
_TRANSFORM.fields_by_name['translation'].message_type = _VECTOR3
_TRANSFORM.fields_by_name['rotation'].message_type = _QUATERNION
DESCRIPTOR.message_types_by_name['Axis'] = _AXIS
DESCRIPTOR.message_types_by_name['Vector3'] = _VECTOR3
DESCRIPTOR.message_types_by_name['Quaternion'] = _QUATERNION
DESCRIPTOR.message_types_by_name['Pose'] = _POSE
DESCRIPTOR.message_types_by_name['Transform'] = _TRANSFORM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Axis = _reflection.GeneratedProtocolMessageType('Axis', (_message.Message,), {
  'DESCRIPTOR' : _AXIS,
  '__module__' : 'bf_proto.percept.common.geometry_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.common.Axis)
  })
_sym_db.RegisterMessage(Axis)

Vector3 = _reflection.GeneratedProtocolMessageType('Vector3', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR3,
  '__module__' : 'bf_proto.percept.common.geometry_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.common.Vector3)
  })
_sym_db.RegisterMessage(Vector3)

Quaternion = _reflection.GeneratedProtocolMessageType('Quaternion', (_message.Message,), {
  'DESCRIPTOR' : _QUATERNION,
  '__module__' : 'bf_proto.percept.common.geometry_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.common.Quaternion)
  })
_sym_db.RegisterMessage(Quaternion)

Pose = _reflection.GeneratedProtocolMessageType('Pose', (_message.Message,), {
  'DESCRIPTOR' : _POSE,
  '__module__' : 'bf_proto.percept.common.geometry_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.common.Pose)
  })
_sym_db.RegisterMessage(Pose)

Transform = _reflection.GeneratedProtocolMessageType('Transform', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORM,
  '__module__' : 'bf_proto.percept.common.geometry_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.common.Transform)
  })
_sym_db.RegisterMessage(Transform)


# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.common_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Error(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Unknown(google.protobuf.message.Message):
        """*
        Unknown error. Please consult the Blickfeld support team for further information.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        DESCRIPTION_FIELD_NUMBER: builtins.int
        description: typing.Text = ...
        """Description of the unknown error"""

        def __init__(self,
            *,
            description : typing.Optional[typing.Text] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"description",b"description"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"description",b"description"]) -> None: ...

    class NotImplemented(google.protobuf.message.Message):
        """*
        The firmware on the device is not compatible with the BSL version. Update the device or downgrade the BSL.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        REASON_FIELD_NUMBER: builtins.int
        reason: typing.Text = ...
        """Description why this is not implemented"""

        def __init__(self,
            *,
            reason : typing.Optional[typing.Text] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"reason",b"reason"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"reason",b"reason"]) -> None: ...

    class Empty(google.protobuf.message.Message):
        """*
        The server sent an empty message.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class ServerImplementation(google.protobuf.message.Message):
        """*
        The server failed to process the request.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class InvalidRequest(google.protobuf.message.Message):
        """*
        Validation of the sent request failed, please send a request with-in a valid range.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        VALIDATION_ERROR_FIELD_NUMBER: builtins.int
        CONSTRAINTS_FIELD_NUMBER: builtins.int
        validation_error: typing.Text = ...
        """Validation error string"""

        @property
        def constraints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[blickfeld.common_pb2.Constraint]:
            """<blockquote>Introduced in BSL v2.14 and firmware v1.14</blockquote> Contains list of failed constraints. The `validation_error` field contains a human-readable output of the constraint validation."""
            pass
        def __init__(self,
            *,
            validation_error : typing.Optional[typing.Text] = ...,
            constraints : typing.Optional[typing.Iterable[blickfeld.common_pb2.Constraint]] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"validation_error",b"validation_error"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"constraints",b"constraints",u"validation_error",b"validation_error"]) -> None: ...

    class ConnectionClosed(google.protobuf.message.Message):
        """*
        The server closed the connection.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class OutdatedServerProtocol(google.protobuf.message.Message):
        """*
        The protocol of the client is too new. Please update the device.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        REQUIRED_VERSION_FIELD_NUMBER: builtins.int
        required_version: builtins.int = ...
        """Version that is required"""

        def __init__(self,
            *,
            required_version : typing.Optional[builtins.int] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"required_version",b"required_version"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"required_version",b"required_version"]) -> None: ...

    class OutdatedClientProtocol(google.protobuf.message.Message):
        """*
        The protocol of the server is too new. Please update the client software.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        REQUIRED_VERSION_FIELD_NUMBER: builtins.int
        required_version: builtins.int = ...
        """Version that is required"""

        def __init__(self,
            *,
            required_version : typing.Optional[builtins.int] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"required_version",b"required_version"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"required_version",b"required_version"]) -> None: ...

    class ScannerBusy(google.protobuf.message.Message):
        """*
        The device is currently busy with another operation. Cancel it and try again.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class WrongOperationMode(google.protobuf.message.Message):
        """*
        The device is set to a different operation mode. Perhaps it is currently being used by another application.
        Change the operation mode and try again if no one else is using it.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class NotAllowed(google.protobuf.message.Message):
        """*
        The requested operation is not allowed.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class HardwareError(google.protobuf.message.Message):
        """*
        The device is in an error state and cannot be operated. Attempt to power-cycle the device or use diagnostic software to read out the hardware state.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class SystemStop(google.protobuf.message.Message):
        """*
        The device stopped unexpectedly and can no longer be operated. Attempt to power cycle the device or use diagnostic software to read-out the hardware state.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class NotFound(google.protobuf.message.Message):
        """*
        The requested data is not available. Please check the request parameters.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class TimeSyncFailed(google.protobuf.message.Message):
        """*
        The time synchronization failed. The NTP daemon failed or timed out.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        NTP_DAEMON_LOG_FIELD_NUMBER: builtins.int
        ntp_daemon_log: typing.Text = ...
        """Log of the NTP daemon"""

        def __init__(self,
            *,
            ntp_daemon_log : typing.Optional[typing.Text] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"ntp_daemon_log",b"ntp_daemon_log"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"ntp_daemon_log",b"ntp_daemon_log"]) -> None: ...

    class NoDeviceDiscovered(google.protobuf.message.Message):
        """*
        No device has been discovered. Check the network connection and power supply of the device. The 'discover' requests may have been blocked by a local or a network firewall.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class UnknownErrorCode(google.protobuf.message.Message):
        """*
        Unknown Error. Please contact the Blickfeld support team and make sure to use compatible BSL and FW versions.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ERROR_CODE_FIELD_NUMBER: builtins.int
        error_code: builtins.int = ...
        """Error code"""

        def __init__(self,
            *,
            error_code : typing.Optional[builtins.int] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"error_code",b"error_code"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"error_code",b"error_code"]) -> None: ...

    class NotInRange(google.protobuf.message.Message):
        """*
        The requested parameter is not within the valid range.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        PARAMETER_FIELD_NUMBER: builtins.int
        MINIMUM_FIELD_NUMBER: builtins.int
        MAXIMUM_FIELD_NUMBER: builtins.int
        REQUESTED_FIELD_NUMBER: builtins.int
        UNIT_FIELD_NUMBER: builtins.int
        parameter: typing.Text = ...
        """The parameter, which was not in range"""

        minimum: builtins.float = ...
        """Minimum value of the parameter"""

        maximum: builtins.float = ...
        """Maximum value of the parameter"""

        requested: builtins.float = ...
        """Requested value of the parameter"""

        unit: typing.Text = ...
        """Unit of the parameter"""

        def __init__(self,
            *,
            parameter : typing.Optional[typing.Text] = ...,
            minimum : typing.Optional[builtins.float] = ...,
            maximum : typing.Optional[builtins.float] = ...,
            requested : typing.Optional[builtins.float] = ...,
            unit : typing.Optional[typing.Text] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"maximum",b"maximum",u"minimum",b"minimum",u"parameter",b"parameter",u"requested",b"requested",u"unit",b"unit"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"maximum",b"maximum",u"minimum",b"minimum",u"parameter",b"parameter",u"requested",b"requested",u"unit",b"unit"]) -> None: ...

    class NotSupported(google.protobuf.message.Message):
        """*
        The action is not supported by the current client or server API. Check the versions of the client and firmware software and read the changelog.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        REASON_FIELD_NUMBER: builtins.int
        reason: typing.Text = ...
        """Description why this is not supported"""

        def __init__(self,
            *,
            reason : typing.Optional[typing.Text] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"reason",b"reason"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"reason",b"reason"]) -> None: ...

    class ConnectionAbort(google.protobuf.message.Message):
        """*
        During reading, the connection to the device got aborted.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        DETAILS_FIELD_NUMBER: builtins.int
        details: typing.Text = ...
        def __init__(self,
            *,
            details : typing.Optional[typing.Text] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"details",b"details"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"details",b"details"]) -> None: ...

    UNKNOWN_FIELD_NUMBER: builtins.int
    NOT_IMPLEMENTED_FIELD_NUMBER: builtins.int
    EMPTY_FIELD_NUMBER: builtins.int
    SERVER_IMPLEMENTATION_FIELD_NUMBER: builtins.int
    INVALID_REQUEST_FIELD_NUMBER: builtins.int
    CONNECTION_CLOSED_FIELD_NUMBER: builtins.int
    OUTDATED_SERVER_PROTOCOL_FIELD_NUMBER: builtins.int
    OUTDATED_CLIENT_PROTOCOL_FIELD_NUMBER: builtins.int
    SCANNER_BUSY_FIELD_NUMBER: builtins.int
    WRONG_OPERATION_MODE_FIELD_NUMBER: builtins.int
    NOT_ALLOWED_FIELD_NUMBER: builtins.int
    HARDWARE_ERROR_FIELD_NUMBER: builtins.int
    SYSTEM_STOP_FIELD_NUMBER: builtins.int
    NOT_FOUND_FIELD_NUMBER: builtins.int
    UNKNOWN_ERROR_CODE_FIELD_NUMBER: builtins.int
    NOT_IN_RANGE_FIELD_NUMBER: builtins.int
    TIME_SYNC_FAILED_FIELD_NUMBER: builtins.int
    NO_DEVICE_DISCOVERED_FIELD_NUMBER: builtins.int
    NOT_SUPPORTED_FIELD_NUMBER: builtins.int
    CONNECTION_ABORT_FIELD_NUMBER: builtins.int
    @property
    def unknown(self) -> global___Error.Unknown:
        """Refer to [Unknown](#blickfeld.protocol.Error.Unknown)"""
        pass
    @property
    def not_implemented(self) -> global___Error.NotImplemented:
        """Refer to [NotImplemented](#blickfeld.protocol.Error.NotImplemented)"""
        pass
    @property
    def empty(self) -> global___Error.Empty:
        """Refer to [Empty](#blickfeld.protocol.Error.Empty)"""
        pass
    @property
    def server_implementation(self) -> global___Error.ServerImplementation:
        """Refer to [ServerImplementation](#blickfeld.protocol.Error.ServerImplementation)"""
        pass
    @property
    def invalid_request(self) -> global___Error.InvalidRequest:
        """Refer to [InvalidRequest](#blickfeld.protocol.Error.InvalidRequest)"""
        pass
    @property
    def connection_closed(self) -> global___Error.ConnectionClosed:
        """Refer to [ConnectionClosed](#blickfeld.protocol.Error.ConnectionClosed)"""
        pass
    @property
    def outdated_server_protocol(self) -> global___Error.OutdatedServerProtocol:
        """Refer to [OutdatedServerProtocol](#blickfeld.protocol.Error.OutdatedServerProtocol)"""
        pass
    @property
    def outdated_client_protocol(self) -> global___Error.OutdatedClientProtocol:
        """Refer to [OutdatedClientProtocol](#blickfeld.protocol.Error.OutdatedClientProtocol)"""
        pass
    @property
    def scanner_busy(self) -> global___Error.ScannerBusy:
        """Refer to [ScannerBusy](#blickfeld.protocol.Error.ScannerBusy)"""
        pass
    @property
    def wrong_operation_mode(self) -> global___Error.WrongOperationMode:
        """Refer to [WrongOperationMode](#blickfeld.protocol.Error.WrongOperationMode)"""
        pass
    @property
    def not_allowed(self) -> global___Error.NotAllowed:
        """Refer to [NotAllowed](#blickfeld.protocol.Error.NotAllowed)"""
        pass
    @property
    def hardware_error(self) -> global___Error.HardwareError:
        """Refer to [HardwareError](#blickfeld.protocol.Error.HardwareError)"""
        pass
    @property
    def system_stop(self) -> global___Error.SystemStop:
        """Refer to [SystemStop](#blickfeld.protocol.Error.SystemStop)"""
        pass
    @property
    def not_found(self) -> global___Error.NotFound:
        """Refer to [NotFound](#blickfeld.protocol.Error.NotFound)"""
        pass
    @property
    def unknown_error_code(self) -> global___Error.UnknownErrorCode:
        """Refer to [UnknownErrorCode](#blickfeld.protocol.Error.UnknownErrorCode)"""
        pass
    @property
    def not_in_range(self) -> global___Error.NotInRange:
        """Refer to [NotInRange](#blickfeld.protocol.Error.NotInRange)"""
        pass
    @property
    def time_sync_failed(self) -> global___Error.TimeSyncFailed:
        """Refer to [TimeSyncFailed](#blickfeld.protocol.Error.TimeSyncFailed)"""
        pass
    @property
    def no_device_discovered(self) -> global___Error.NoDeviceDiscovered:
        """Refer to [NoDeviceDiscovered](#blickfeld.protocol.Error.NoDeviceDiscovered)"""
        pass
    @property
    def not_supported(self) -> global___Error.NotSupported:
        """Refer to [NotSupported](#blickfeld.protocol.Error.NotSupported)"""
        pass
    @property
    def connection_abort(self) -> global___Error.ConnectionAbort:
        """Refer to [ConnectionAbort](#blickfeld.protocol.Error.ConnectionAbort)"""
        pass
    def __init__(self,
        *,
        unknown : typing.Optional[global___Error.Unknown] = ...,
        not_implemented : typing.Optional[global___Error.NotImplemented] = ...,
        empty : typing.Optional[global___Error.Empty] = ...,
        server_implementation : typing.Optional[global___Error.ServerImplementation] = ...,
        invalid_request : typing.Optional[global___Error.InvalidRequest] = ...,
        connection_closed : typing.Optional[global___Error.ConnectionClosed] = ...,
        outdated_server_protocol : typing.Optional[global___Error.OutdatedServerProtocol] = ...,
        outdated_client_protocol : typing.Optional[global___Error.OutdatedClientProtocol] = ...,
        scanner_busy : typing.Optional[global___Error.ScannerBusy] = ...,
        wrong_operation_mode : typing.Optional[global___Error.WrongOperationMode] = ...,
        not_allowed : typing.Optional[global___Error.NotAllowed] = ...,
        hardware_error : typing.Optional[global___Error.HardwareError] = ...,
        system_stop : typing.Optional[global___Error.SystemStop] = ...,
        not_found : typing.Optional[global___Error.NotFound] = ...,
        unknown_error_code : typing.Optional[global___Error.UnknownErrorCode] = ...,
        not_in_range : typing.Optional[global___Error.NotInRange] = ...,
        time_sync_failed : typing.Optional[global___Error.TimeSyncFailed] = ...,
        no_device_discovered : typing.Optional[global___Error.NoDeviceDiscovered] = ...,
        not_supported : typing.Optional[global___Error.NotSupported] = ...,
        connection_abort : typing.Optional[global___Error.ConnectionAbort] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"connection_abort",b"connection_abort",u"connection_closed",b"connection_closed",u"empty",b"empty",u"error",b"error",u"hardware_error",b"hardware_error",u"invalid_request",b"invalid_request",u"no_device_discovered",b"no_device_discovered",u"not_allowed",b"not_allowed",u"not_found",b"not_found",u"not_implemented",b"not_implemented",u"not_in_range",b"not_in_range",u"not_supported",b"not_supported",u"outdated_client_protocol",b"outdated_client_protocol",u"outdated_server_protocol",b"outdated_server_protocol",u"scanner_busy",b"scanner_busy",u"server_implementation",b"server_implementation",u"system_stop",b"system_stop",u"time_sync_failed",b"time_sync_failed",u"unknown",b"unknown",u"unknown_error_code",b"unknown_error_code",u"wrong_operation_mode",b"wrong_operation_mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"connection_abort",b"connection_abort",u"connection_closed",b"connection_closed",u"empty",b"empty",u"error",b"error",u"hardware_error",b"hardware_error",u"invalid_request",b"invalid_request",u"no_device_discovered",b"no_device_discovered",u"not_allowed",b"not_allowed",u"not_found",b"not_found",u"not_implemented",b"not_implemented",u"not_in_range",b"not_in_range",u"not_supported",b"not_supported",u"outdated_client_protocol",b"outdated_client_protocol",u"outdated_server_protocol",b"outdated_server_protocol",u"scanner_busy",b"scanner_busy",u"server_implementation",b"server_implementation",u"system_stop",b"system_stop",u"time_sync_failed",b"time_sync_failed",u"unknown",b"unknown",u"unknown_error_code",b"unknown_error_code",u"wrong_operation_mode",b"wrong_operation_mode"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"error",b"error"]) -> typing.Optional[typing_extensions.Literal["unknown","not_implemented","empty","server_implementation","invalid_request","connection_closed","outdated_server_protocol","outdated_client_protocol","scanner_busy","wrong_operation_mode","not_allowed","hardware_error","system_stop","not_found","unknown_error_code","not_in_range","time_sync_failed","no_device_discovered","not_supported","connection_abort"]]: ...
global___Error = Error
